# rmtoo-analytics-descwords

NAME
DESCRIPTION
IDEA
CONFIGURATION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-analytics-descwords - requirements management tool: analytics module for words in tag description

## DESCRIPTION

The rmtoo analytics module descwords uses a heuristic to evaluate the quality of the Description tag of the requirement.

## IDEA

For each supported language a set of often used words are defined as regular expressions. When a regular expression matches, depending on the value of the regular expression, a specific number is added.

E.g. good words like must have a positive value, bad words like possible have a negative value.

All these values are added for each description. When the result is negative, it is assumed that the quality of the requirement is not good. In this case an error is printed.

## CONFIGURATION

Currently implemented are word (regular expression) lists for en_GB and de_DE.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later